@@ -29,7 +29,6 @@ from .fields import (
     Array,
     Map,
     ClassReference,
-    Enum,
     MultiFieldWrapper,
     Boolean,
     Tuple,
@@ -47,7 +46,7 @@ from .fields import (
     Deque,
     Generator,
 )
-
+from .enum import Enum
 
 # pylint: disable=too-many-locals, too-many-arguments, too-many-branches
 
@@ -276,7 +275,7 @@ def deserialize_single_field(  # pylint: disable=too-many-branches
     """
     if source_val is None and (ignore_none or isinstance(field, NoneField)):
         return source_val
-    if isinstance(field, (Number, String, Enum, Boolean)):
+    if isinstance(field, (Number, String, Boolean)):
         field._validate(source_val)
         value = source_val
     elif (
@@ -614,9 +613,7 @@ def serialize_multifield_wrapper(fields, name, val, mapper, camel_case_convert):
 
 
 def serialize_val(field_definition, name, val, mapper=None, camel_case_convert=False):
-    if isinstance(field_definition, SerializableField) and isinstance(
-        field_definition, Field
-    ):
+    if isinstance(field_definition, SerializableField):
         return field_definition.serialize(val)
     if isinstance(field_definition, MultiFieldWrapper):
         return serialize_multifield_wrapper(
@@ -628,10 +625,6 @@ def serialize_val(field_definition, name, val, mapper=None, camel_case_convert=F
         isinstance(val, (int, float, str, bool)) or val is None
     ):
         return val
-    if isinstance(val, enum.Enum):
-        return val.name
-    if isinstance(field_definition, Enum) and isinstance(val, (int, float, str, bool)):
-        return val
     if isinstance(field_definition, SizedCollection):
         if isinstance(field_definition, Map):
             if (
